@@ -28,10 +28,6 @@
 # error missing include: sys/time.h required
 #endif
 
-#ifndef HAVE_GETOPT_H
-# error missing include: getopt.h required
-#endif
-
 #ifndef HAVE_ERRNO_H
 # error missing include: errno.h required
 #endif
